==> wiki3_5_5.zip: wiki3_5_5/plugin/rename/RenameHandler.pm <==
###############################################################################
# 
# ڡ̾ΤѹڡΥԡ򤹤ϥɥ顣
# renameեåƤӽФޤ
# 
###############################################################################
package plugin::rename::RenameHandler;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# μ¹
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	
	return $self->do_rename($wiki);
}

#==============================================================================
# ͡¹
#==============================================================================
sub do_rename {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;

	my $pagename    = $cgi->param("page");
	my $newpagename = $cgi->param("newpage");
	my $do          = $cgi->param("do");
	my $time        = $wiki->get_last_modified($pagename);
	my $buf         = "";
	my $login       = $wiki->get_login_info();

	# 顼å
	if($newpagename eq ""){
		return $wiki->error("ڡꤵƤޤ!!");
	}
	if($newpagename =~ /\[|\]/){
		return $wiki->error("ڡ̾˥֥饱åȤޤ뤳ȤϤǤޤ");
	}
	if($newpagename =~ /:/){
		return $wiki->error("ڡ̾˥ޤ뤳ȤϤǤޤ");
	}
	if($wiki->page_exists($newpagename)){
		return $wiki->error("˥͡Υڡ¸ߤޤ!!");
	}
	if($newpagename eq $pagename){
		return $wiki->error("ƱΥڡꤵƤޤ!!");
	}
	if(!$wiki->can_modify_page($pagename) || !$wiki->can_modify_page($newpagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	if($wiki->page_exists($pagename)){
		if($cgi->param("lastmodified") < $time){
			return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
		}
	}

	# FrontPageư褦Ȥˤϥ顼
	if($pagename eq $wiki->config("frontpage") && $do ne "copy"){
		return $wiki->error($wiki->config("frontpage")."ư뤳ȤϤǤޤ");
	}

	# ԡ
	$wiki->do_hook("rename");
	my $content = $wiki->get_page($pagename);
	$wiki->save_page($newpagename,$content);
	
	# 
	if($do eq "move"){
		$wiki->save_page($pagename,'');
	}elsif($do eq "movewm"){
		$wiki->save_page($pagename,'[['.$newpagename.']]˰ưޤ');
	}

	# եåεưֵѥå
	if($do eq "copy"){
		$wiki->set_title($pagename."򥳥ԡޤ");
		return $cgi->escapeHTML($pagename)."򥳥ԡޤ";
	} else {
		$wiki->set_title($pagename."͡षޤ");
		return $cgi->escapeHTML($pagename)."͡षޤ";
	}
}

1;

==> wiki3_6_0.zip: wiki3_6_0/plugin/rename/RenameHandler.pm <==
###############################################################################
# 
# ڡ̾ΤѹڡΥԡ򤹤ϥɥ顣
# renameեåƤӽФޤ
# 
###############################################################################
package plugin::rename::RenameHandler;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# μ¹
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	
	return $self->do_rename($wiki);
}

#==============================================================================
# ͡¹
#==============================================================================
sub do_rename {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;

	my $pagename    = $cgi->param("page");
	my $newpagename = $cgi->param("newpage");
	my $do          = $cgi->param("do");
	my $time        = $wiki->get_last_modified($pagename);
	my $buf         = "";
	my $login       = $wiki->get_login_info();

	# 顼å
	if($newpagename eq ""){
		return $wiki->error("ڡꤵƤޤ!!");
	}
	if($newpagename =~ /[\|:\[\]]/){
		return $wiki->error("ڡ̾˻ѤǤʤʸޤޤƤޤ");
	}
	if($wiki->page_exists($newpagename)){
		return $wiki->error("˥͡Υڡ¸ߤޤ!!");
	}
	if($newpagename eq $pagename){
		return $wiki->error("ƱΥڡꤵƤޤ!!");
	}
	if(!$wiki->can_modify_page($pagename) || !$wiki->can_modify_page($newpagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	if($wiki->page_exists($pagename)){
		if($cgi->param("lastmodified") < $time){
			return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
		}
	}

	# FrontPageư褦Ȥˤϥ顼
	if($pagename eq $wiki->config("frontpage") && $do ne "copy"){
		return $wiki->error($wiki->config("frontpage")."ư뤳ȤϤǤޤ");
	}

	# ԡ
	$wiki->do_hook("rename");
	my $content = $wiki->get_page($pagename);
	$wiki->save_page($newpagename,$content);
	
	# 
	if($do eq "move"){
		$wiki->save_page($pagename,'');
	}elsif($do eq "movewm"){
		$wiki->save_page($pagename,'[['.$newpagename.']]˰ưޤ');
	}

	# եåεưֵѥå
	if($do eq "copy"){
		$wiki->set_title($pagename."򥳥ԡޤ");
		return $cgi->escapeHTML($pagename)."򥳥ԡޤ";
	} else {
		$wiki->set_title($pagename."͡षޤ");
		return $cgi->escapeHTML($pagename)."͡षޤ";
	}
}

1;
